"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRecord = void 0;
const uuid_1 = require("uuid");
const handleErrors_1 = require("../utils/handleErrors");
const db_1 = require("../utils/db");
const bcrypt_1 = require("bcrypt");
const generate_password_1 = require("generate-password");
const check_password_strength_1 = require("check-password-strength");
class UserRecord {
    constructor(obj) {
        if (!obj.id) {
            obj.id = (0, uuid_1.v4)();
        }
        const passwordIsStrong = (0, check_password_strength_1.passwordStrength)(obj.passwordhash).id;
        if (obj.name.length < 3 || obj.name.length > 30) {
            throw new handleErrors_1.ValidationError('name should be between 3 and 30 characters');
        }
        if (obj.email.indexOf('@') < 0) {
            throw new handleErrors_1.ValidationError('invalid email address  !');
        }
        if (!obj.passwordhash || obj.passwordhash.length < 6) {
            throw new handleErrors_1.ValidationError('invalid or to short password  !');
        }
        if (passwordIsStrong < 2) {
            throw new handleErrors_1.ValidationError('password is too weak, add number or special characters');
        }
        this.isverified = false;
        this.avatar = obj.avatar;
        this.email = obj.email;
        this.id = obj.id;
        this.name = obj.name;
        this.passwordhash = obj.passwordhash;
        this.verification_code = null;
    }
    static resetPassword() {
        return __awaiter(this, void 0, void 0, function* () {
            return (0, generate_password_1.generate)({
                length: 10,
                numbers: true,
            });
        });
    }
    static changePassword(id, newPassword) {
        return __awaiter(this, void 0, void 0, function* () {
            const password = yield (0, bcrypt_1.hash)(newPassword, 10);
            db_1.pool.execute("UPDATE `userslist` SET `passwordhash`=:password WHERE `id`=:id", {
                password: password,
                id: id,
            });
        });
    }
    static removeAccount(userName, userId) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `userslist` WHERE `id`=:userId AND `name`=:userName", {
                userName,
                userId,
            });
        });
    }
    static changeAvatar(id, avatar) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `userslist` SET `avatar`=:avatar WHERE `id`=:id", {
                avatar: String(avatar),
                id: id,
            });
        });
    }
    static getOneUser(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const user = yield db_1.pool.execute("SELECT * FROM `userslist` WHERE `id`=:id", {
                id: id,
            });
            return user[0];
        });
    }
    static logIn(userName, password) {
        return __awaiter(this, void 0, void 0, function* () {
            const [result] = yield db_1.pool.execute("SELECT * FROM `userslist` WHERE `name`=:userName", {
                userName: userName,
            });
            if (!result[0]) {
                return null;
            }
            const check = yield (0, bcrypt_1.compare)(password, result[0].passwordhash);
            if (check) {
                if (result[0].name === userName) {
                    return result[0];
                }
                else
                    return null;
            }
            else
                return null;
        });
    }
    insertIntoDb() {
        return __awaiter(this, void 0, void 0, function* () {
            const verificationCode = Math.floor(Math.random() * (9999 - 8000) + 1999);
            const hashPassword = yield (0, bcrypt_1.hash)(this.passwordhash, 10);
            yield db_1.pool.execute("INSERT INTO `userslist`(`id`, `name`, `passwordhash`, `email`,`avatar`,`verification_code`) VALUES (:id,:name,:passwordhash,:email,:avatar,:verificationCode)", {
                id: this.id,
                name: this.name,
                passwordhash: hashPassword,
                email: this.email,
                avatar: this.avatar,
                verificationCode: verificationCode,
            });
            return verificationCode;
        });
    }
}
exports.UserRecord = UserRecord;
//# sourceMappingURL=user.record.js.map