"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.commentsRouter = void 0;
const express_1 = require("express");
const handleErrors_1 = require("../utils/handleErrors");
const uuid_1 = require("uuid");
const commentsRepository_1 = require("../utils/repositories/commentsRepository/commentsRepository");
exports.commentsRouter = (0, express_1.Router)()
    .delete('/likes', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const { commentId, user, type } = req.body;
        const id = (0, uuid_1.v4)();
        const mainCommentId = type === 'comment' ? commentId : yield commentsRepository_1.CommentsRepository.getMainCommentIdFromAnswer(commentId);
        const dislikesList = yield commentsRepository_1.CommentsRepository.getDislikes(user, commentId);
        if (dislikesList.length === 0) {
            const likesList = yield commentsRepository_1.CommentsRepository.getLikes(user, commentId);
            if (likesList.length > 0) {
                yield commentsRepository_1.CommentsRepository.deleteLike(user, commentId);
                if (type === 'comment') {
                    const likesNumber = yield commentsRepository_1.CommentsRepository.getLikesCountFromComment(commentId, type);
                    const newLikesNumber = --likesNumber.liked;
                    yield commentsRepository_1.CommentsRepository.updateLikesCountInComment(commentId, newLikesNumber, type);
                }
                if (type === 'answer') {
                    const likesNumber = yield commentsRepository_1.CommentsRepository.getLikesCountFromComment(commentId, type);
                    const newLikesNumber = --likesNumber.liked;
                    yield commentsRepository_1.CommentsRepository.updateLikesCountInComment(commentId, newLikesNumber, type);
                }
            }
            yield commentsRepository_1.CommentsRepository.insertDislikeIntoDatabase(id, commentId, user, mainCommentId);
            if (type === 'comment') {
                const dislikesCount = yield commentsRepository_1.CommentsRepository.getDislikesCountFromComment(commentId, type);
                const newDislikesNumber = ++dislikesCount.disliked;
                yield commentsRepository_1.CommentsRepository.updateDislikesCountInComment(commentId, newDislikesNumber, type);
            }
            if (type === 'answer') {
                const dislikesCount = yield commentsRepository_1.CommentsRepository.getDislikesCountFromComment(commentId, type);
                const newDislikesNumber = ++dislikesCount.disliked;
                yield commentsRepository_1.CommentsRepository.updateDislikesCountInComment(commentId, newDislikesNumber, type);
            }
            res.json({
                message: 'dislike added'
            });
        }
        else {
            res.json({
                message: 'comment already disliked'
            });
        }
    }
    catch (e) {
        throw new handleErrors_1.ValidationError(e);
    }
}))
    .post('/likes', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const { commentId, user, type } = req.body;
        const id = (0, uuid_1.v4)();
        const likesList = yield commentsRepository_1.CommentsRepository.getLikes(user, commentId);
        const mainCommentId = type === 'comment' ? commentId : yield commentsRepository_1.CommentsRepository.getMainCommentIdFromAnswer(commentId);
        if (likesList.length === 0) {
            const dislikesList = yield commentsRepository_1.CommentsRepository.getDislikes(user, commentId);
            if (dislikesList.length > 0) {
                yield commentsRepository_1.CommentsRepository.deleteDislike(user, commentId);
                if (type === 'comment') {
                    const dislikesCount = yield commentsRepository_1.CommentsRepository.getDislikesCountFromComment(commentId, type);
                    const newDislikesNumber = --dislikesCount.disliked;
                    yield commentsRepository_1.CommentsRepository.updateDislikesCountInComment(commentId, newDislikesNumber, type);
                }
                if (type === 'answer') {
                    const dislikesCount = yield commentsRepository_1.CommentsRepository.getDislikesCountFromComment(commentId, type);
                    const newDislikesNumber = --dislikesCount.disliked;
                    yield commentsRepository_1.CommentsRepository.updateDislikesCountInComment(commentId, newDislikesNumber, type);
                }
            }
            yield commentsRepository_1.CommentsRepository.insertLikeIntoDatabase(id, commentId, user, mainCommentId);
            if (type === 'comment') {
                const likesCount = yield commentsRepository_1.CommentsRepository.getLikesCountFromComment(commentId, type);
                const newLikesCount = ++likesCount.liked;
                yield commentsRepository_1.CommentsRepository.updateLikesCountInComment(commentId, newLikesCount, type);
            }
            if (type === 'answer') {
                const likesCount = yield commentsRepository_1.CommentsRepository.getLikesCountFromComment(commentId, type);
                const newLikesCount = ++likesCount.liked;
                yield commentsRepository_1.CommentsRepository.updateLikesCountInComment(commentId, newLikesCount, type);
            }
            res.json({
                message: 'like added'
            });
        }
        else {
            res.json({
                message: 'already liked this comment'
            });
        }
    }
    catch (e) {
        throw new handleErrors_1.ValidationError(e);
    }
}))
    .post('/answers', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const { mainCommentId, comment, user, avatar } = req.body;
        const newId = (0, uuid_1.v4)();
        yield commentsRepository_1.CommentsRepository.addAnswerToComment(newId, mainCommentId, comment, user, avatar);
        res.json({ message: 'answer to comment added' });
    }
    catch (e) {
        throw new handleErrors_1.ValidationError(e);
    }
}))
    .put('/answers/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const id = req.params.id;
        const { comment } = req.body;
        yield commentsRepository_1.CommentsRepository.updateAnswerToComment(id, comment);
        res.json({
            message: 'answer to comment updated',
        });
    }
    catch (e) {
        throw new handleErrors_1.ValidationError(e);
    }
}))
    .get('/answers/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const id = req.params.id;
        const data = yield commentsRepository_1.CommentsRepository.getAnswersForComment(id);
        res.json(data);
    }
    catch (e) {
        throw new handleErrors_1.ValidationError(e);
    }
}))
    .get('/:id/:type', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const { id, type } = req.params;
        const response = yield commentsRepository_1.CommentsRepository.getCommentsByMovieId(id, type);
        res.json(response);
    }
    catch (e) {
        res.json({
            message: e,
            result: [],
        });
    }
}))
    .delete('/answers', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const { id } = req.body;
        yield commentsRepository_1.CommentsRepository.deleteAnswerToComment(id);
        yield commentsRepository_1.CommentsRepository.deleteAllLikesByCommentId(id);
        yield commentsRepository_1.CommentsRepository.deleteAllDislikesByCommentId(id);
        yield commentsRepository_1.CommentsRepository.deleteAllAnswersByCommentId(id);
        res.json({
            message: 'answer to comment deleted'
        });
    }
    catch (e) {
        throw new handleErrors_1.ValidationError(e);
    }
}))
    .delete('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const id = req.body.id;
        yield commentsRepository_1.CommentsRepository.deleteComment(id);
        yield commentsRepository_1.CommentsRepository.deleteAllLikesByCommentId(id);
        yield commentsRepository_1.CommentsRepository.deleteAllDislikesByCommentId(id);
        yield commentsRepository_1.CommentsRepository.deleteAllAnswersByCommentId(id);
        res.json({
            message: 'comment deleted...',
        });
    }
    catch (e) {
        throw new handleErrors_1.ValidationError(e);
    }
}))
    .post('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const { comment, commented_id, name, avatar, type } = req.body;
        const id = (0, uuid_1.v4)();
        if (comment === ' ' || comment === '') {
            res.json({
                message: 'empty comment'
            });
        }
        else {
            yield commentsRepository_1.CommentsRepository.insertCommentIntoDatabase(id, commented_id, name, comment, avatar, type);
            res.json({
                message: 'comment added...',
            });
        }
    }
    catch (e) {
        throw new handleErrors_1.ValidationError(e);
    }
}))
    .put('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const { id, newComment } = req.body;
        if (!newComment || newComment === ' ') {
            res.json({ message: 'comment is empty !' });
        }
        else {
            yield commentsRepository_1.CommentsRepository.updateComment(id, newComment);
            res.json({ message: 'comment updated' });
        }
    }
    catch (e) {
        throw new handleErrors_1.ValidationError(e);
    }
}));
//# sourceMappingURL=commentsRouter.js.map