"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.userRouter = void 0;
const express_1 = require("express");
const user_record_1 = require("../records/user.record");
const sendVerificationEmail_1 = require("../utils/sendVerificationEmail");
const handleErrors_1 = require("../utils/handleErrors");
const noVerifiedAccountsRemover_1 = require("../utils/noVerifiedAccountsRemover");
const favouriteMovies_1 = require("../utils/repositories/favouriteMoviesRepository/favouriteMovies");
exports.userRouter = (0, express_1.Router)()
    .post('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const obj = yield req.body;
        const newUser = new user_record_1.UserRecord(obj);
        const verificationNumber = yield newUser.insertIntoDb();
        (0, sendVerificationEmail_1.sendVerEmail)(newUser.email, verificationNumber);
        res.json(Object.assign(Object.assign({}, newUser), { passwordhash: '' }));
    }
    catch (err) {
        throw new handleErrors_1.ValidationError(err);
    }
}))
    .post('/:name', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield (0, noVerifiedAccountsRemover_1.noVerifiedAccountsRemover)();
        const id = req.params.name;
        const password = req.body.pass;
        const user = yield user_record_1.UserRecord.logIn(id, password);
        if (!user) {
            res.json(null);
        }
        else {
            if (!user.isverified) {
                res.json({
                    userNotVerified: true,
                });
            }
            else {
                res.json(Object.assign(Object.assign({}, user), { passwordhash: '' }));
            }
        }
    }
    catch (e) {
        throw new handleErrors_1.ValidationError(e);
    }
}))
    .get('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const user = yield user_record_1.UserRecord.getOneUser(req.params.id);
        res.json(user);
    }
    catch (e) {
        throw new handleErrors_1.ValidationError(e);
    }
})).put('/change_password/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    yield user_record_1.UserRecord.changePassword(req.params.id, req.body.password);
    res.json({
        message: 'password changed'
    });
}))
    .put('/:id', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const id = req.params.id;
        const avatar = req.body.avatar;
        yield user_record_1.UserRecord.changeAvatar(id, avatar);
    }
    catch (e) {
        throw new handleErrors_1.ValidationError(e);
    }
}))
    .delete('/', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const { userName, userId } = req.body;
        yield user_record_1.UserRecord.removeAccount(userName, userId);
        yield favouriteMovies_1.FavouriteMovies.deleteAllFavouriteMoviesAndActors(userName);
        res.json({
            message: `${userName} account was deleted.`
        });
    }
    catch (e) {
        throw new handleErrors_1.ValidationError(e);
    }
}));
//# sourceMappingURL=userRouter.js.map