"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommentsRepository = void 0;
const db_1 = require("../../db");
class CommentsRepository {
    static insertDislikeIntoDatabase(id, commentId, user, mainCommentId) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("INSERT INTO `comments_dislikes`(`id`, `disliked_id`, `user`,`original_comment_id`) VALUES (:id,:disliked_id,:user,:mainCommentId)", {
                id,
                disliked_id: commentId,
                user,
                mainCommentId
            });
        });
    }
    static insertLikeIntoDatabase(id, commentId, user, mainCommentId) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("INSERT INTO `comments_likes`(`id`, `liked_id`, `user`,`original_comment_id`) VALUES (:id,:liked_id,:user,:mainCommentId)", {
                id,
                liked_id: commentId,
                user,
                mainCommentId,
            });
        });
    }
    static updateDislikesCountInComment(commentId, newLikesNumber, type) {
        return __awaiter(this, void 0, void 0, function* () {
            if (type === 'comment') {
                yield db_1.pool.execute("UPDATE `comments` SET `disliked`=:number WHERE `id`=:id", {
                    id: commentId,
                    number: newLikesNumber,
                });
            }
            if (type === 'answer') {
                yield db_1.pool.execute("UPDATE `comments_answers` SET `disliked`=:number WHERE `id`=:id", {
                    id: commentId,
                    number: newLikesNumber,
                });
            }
        });
    }
    static updateLikesCountInComment(commentId, newLikesNumber, type) {
        return __awaiter(this, void 0, void 0, function* () {
            if (type === 'comment') {
                yield db_1.pool.execute("UPDATE `comments` SET `liked`=:number WHERE `id`=:id", {
                    id: commentId,
                    number: newLikesNumber,
                });
            }
            if (type === 'answer') {
                yield db_1.pool.execute("UPDATE `comments_answers` SET `liked`=:number WHERE `id`=:id", {
                    id: commentId,
                    number: newLikesNumber,
                });
            }
        });
    }
    static getDislikesCountFromComment(commentId, type) {
        return __awaiter(this, void 0, void 0, function* () {
            if (type === 'comment') {
                let likesNumber = yield db_1.pool.execute("SELECT  `disliked` FROM `comments` WHERE `id`=:commentId", {
                    commentId,
                });
                return likesNumber[0][0];
            }
            if (type === 'answer') {
                let likesNumber = yield db_1.pool.execute("SELECT  `disliked` FROM `comments_answers` WHERE `id`=:commentId", {
                    commentId,
                });
                return likesNumber[0][0];
            }
        });
    }
    static getLikesCountFromComment(commentId, type) {
        return __awaiter(this, void 0, void 0, function* () {
            if (type === 'comment') {
                let likesNumber = yield db_1.pool.execute("SELECT  `liked` FROM `comments` WHERE `id`=:commentId", {
                    commentId,
                });
                return likesNumber[0][0];
            }
            if (type === 'answer') {
                let likesNumber = yield db_1.pool.execute("SELECT  `liked` FROM `comments_answers` WHERE `id`=:commentId", {
                    commentId,
                });
                return likesNumber[0][0];
            }
        });
    }
    static getDislikes(user, commentId) {
        return __awaiter(this, void 0, void 0, function* () {
            const data = yield db_1.pool.execute("SELECT `disliked_id`, `user` FROM `comments_dislikes` WHERE `user`=:user AND `disliked_id`=:commentId", {
                user,
                commentId,
            });
            return data[0];
        });
    }
    static getLikes(user, commentId) {
        return __awaiter(this, void 0, void 0, function* () {
            const data = yield db_1.pool.execute("SELECT * FROM `comments_likes` WHERE `user`=:user AND `liked_id`=:commentId", {
                user,
                commentId,
            });
            return data[0];
        });
    }
    static deleteLike(user, commentId) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `comments_likes` WHERE `user`=:user AND `liked_id`=:commentId", {
                user,
                commentId,
            });
        });
    }
    static deleteAllLikesByCommentId(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `comments_likes` WHERE `original_comment_id`=:id", {
                id,
            });
        });
    }
    static deleteDislike(user, commentId) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `comments_dislikes` WHERE `user`=:user AND `disliked_id`=:commentId", {
                user,
                commentId,
            });
        });
    }
    static deleteAllDislikesByCommentId(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `comments_dislikes` WHERE `original_comment_id`=:id", {
                id,
            });
        });
    }
    static getMainCommentIdFromAnswer(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const mainId = yield db_1.pool.execute("SELECT  `comment_id` FROM `comments_answers` WHERE `id` = :id", {
                id,
            });
            return mainId[0][0].comment_id;
        });
    }
    static addAnswerToComment(newId, mainCommentId, comment, user, avatar) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("INSERT INTO `comments_answers`(`id`, `comment_id`, `comment`,  `user`, `avatar`) VALUES (:id,:mainCommentId,:comment,:user,:avatar)", {
                id: newId,
                mainCommentId,
                comment,
                user,
                avatar,
            });
        });
    }
    static updateAnswerToComment(id, comment) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `comments_answers` SET `comment`=:comment WHERE `id`=:id", {
                id,
                comment,
            });
        });
    }
    static getAnswersForComment(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield db_1.pool.execute("SELECT * FROM `comments_answers` WHERE `comment_id` = :id", {
                id,
            });
            return {
                result: response[0],
                message: 'comments loaded'
            };
        });
    }
    static getCommentsByMovieId(id, type) {
        return __awaiter(this, void 0, void 0, function* () {
            const data = yield db_1.pool.execute("SELECT `name`, `comment`, `created_at`,`id`, `avatar`,`liked`,`disliked` FROM `comments` WHERE `commented_id`=:id AND `type`=:type ORDER BY `created_at` ASC ", {
                id: id,
                type: type,
            });
            return {
                message: 'ok',
                result: data[0],
            };
        });
    }
    static deleteAnswerToComment(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `comments_answers` WHERE `id`=:id", {
                id,
            });
        });
    }
    static deleteAllAnswersByCommentId(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `comments_answers` WHERE `comment_id`=:id", {
                id,
            });
        });
    }
    static deleteComment(id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("DELETE FROM `comments` WHERE `id`=:id", {
                id: id,
            });
        });
    }
    static insertCommentIntoDatabase(id, commented_id, name, comment, avatar, type) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("INSERT INTO `comments`(`id`, `commented_id`, `name`, `comment`, `avatar`, `type`) VALUES (:id,:commented_id,:name,:comment,:avatar,:type)", {
                id,
                commented_id,
                name,
                comment,
                avatar,
                type,
            });
        });
    }
    static updateComment(id, newComment) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `comments` SET `comment`=:newComment,`created_at`=:date WHERE `id`=:id", {
                id,
                newComment,
                date: new Date(),
            });
        });
    }
}
exports.CommentsRepository = CommentsRepository;
//# sourceMappingURL=commentsRepository.js.map